#
# spec file for package laptop-mode-tools
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_tmpfilesdir:%global _tmpfilesdir /usr/lib/tmpfiles.d}
%{!?_udevdir:%global _udevdir  %{_udevrulesdir}/..}

Name:           laptop-mode-tools
Version:        1.74
Release:        3.13
Summary:        The Laptop Mode Tools
License:        GPL-2.0-or-later
Group:          System/Base
URL:            http://rickysarraf.github.io/laptop-mode-tools/
Source:         https://github.com/rickysarraf/laptop-mode-tools/releases/download/%{version}/laptop-mode-tools_%{version}.tar.gz
Source1:        README.SUSE
Patch0:         laptop-mode-1.53_conf.diff
Patch1:         laptop-mode-1.49-new-dirty-ratio-defaults.diff
Patch2:         laptop-mode-1.53-moblin-enable-intel-hda-powersave.patch
Patch3:	harden_laptop-mode.service.patch
Patch4:	harden_lmt-poll.service.patch
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Suggests:       %{name}-gui
BuildArch:      noarch
%{?systemd_requires}

%description
Laptop Mode Tools is a laptop power saving package for Linux systems.
It allows you to extend the battery life of your laptop, in several
ways. It is the primary way to enable the Laptop Mode feature of the
Linux kernel, which lets your hard drive spin down. In addition, it
allows you to tweak a number of other power-related settings using a
simple configuration file.

%package gui
Summary:        Graphical User Interface for the laptop mode tools
Group:          System/Base
BuildRequires:  update-desktop-files
Requires:       %{name} = %{version}
Requires:       python3-qt5
BuildArch:      noarch

%description gui
This package contains a graphical user interface for laptop-mode-tools.

%prep
%autosetup -p1 -n laptop-mode-tools_%{version}
cp %{SOURCE1} .

%build

%install
DESTDIR=%{buildroot} \
MAN_D=%{_mandir} \
INIT_D="none" \
LIB_D=%{_libdir} \
UDEV_D=%{_udevdir} \
SYSTEMD_UNIT_D=%{_unitdir} \
ACPI=disabled PMU=disabled APM=disabled INSTALL=install ./install.sh

# Fix spurious executable permission
chmod 644 %{buildroot}/%{_mandir}/man8/*

# Fix suse-missing-rclink
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rclaptop-mode
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rclmt-poll

# remove pm-utils hook: as soon as DESTDIR is defined, the hook is always installed
rm -rf %{buildroot}%{_prefix}/lib/pm-utils

# Fix insufficient category definition
%suse_update_desktop_file -r laptop-mode-tools Settings HardwareSettings

%pre
%service_add_pre laptop-mode.service lmt-poll.service

%post
%service_add_post laptop-mode.service lmt-poll.service
systemd-tmpfiles --create %{_tmpfilesdir}/laptop-mode.conf

%preun
%service_del_preun laptop-mode.service lmt-poll.service

%postun
%service_del_postun laptop-mode.service lmt-poll.service

%files
%doc README.SUSE
%license COPYING
%dir %{_sysconfdir}/laptop-mode
%config %{_sysconfdir}/laptop-mode/*
%{_sbindir}/*
%exclude %{_sbindir}/*gui*
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/modules/
%dir %{_datadir}/%{name}/module-helpers/
%{_datadir}/%{name}/modules/*
%{_datadir}/%{name}/module-helpers/lm-polling-daemon
%{_datadir}/%{name}/module-helpers/pm-freeze
%{_datadir}/%{name}/module-helpers/pm-helper
%{_datadir}/%{name}/module-helpers/pm-hibernate
%{_datadir}/%{name}/module-helpers/pm-suspend
%{_udevdir}/lmt-udev
%{_udevrulesdir}/99-laptop-mode.rules
%{_mandir}/man8/*
%{_tmpfilesdir}/laptop-mode.conf
%{_unitdir}/laptop-mode.service
%{_unitdir}/laptop-mode.timer
%{_unitdir}/lmt-poll.service

%files gui
%license COPYING
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.svg
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/org.linux.lmt.gui.policy
%{_datadir}/%{name}/lmt.py
%{_sbindir}/*gui*

%changelog
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Thu Sep 30 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_laptop-mode.service.patch
  * harden_lmt-poll.service.patch
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.74
  * With 4.15+ kernels, Linux Intel SATA has a better link power
    saving policy, med_power_with_dipm, which should be the recommended
    one to use
  * Disable defaults for syslog logging
  * Initialize LM_VERBOSE with default to disabled
  * Add power saving module for nouveau cards
  * Disable ethernet module by default
  * Add board-specific folder and documentation
  * Add execute bit on module radeon-dpm
  * Drop unlock because there is no lock acquired
* Tue Aug 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix invalid usage of %%{_libexecdir} (boo#1174075).
* Tue May 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.73.1:
  * Respect black/white lists when disabling autosuspend
  * Add newer power supply names
  * Fix crash due external battery of mouse
  * Honor configuration setting for battery level polling
  * cpufreq: intel_pstate should use performance governors
  * runtime-pm: Speed up by avoiding fork in echo_to_file
  * runtime-pm: Inline echo_to_file_do
  * runtime-pm: Fix echo_to_file* indentation
  * runtime-pm: Speed up by avoiding fork in listed_by_{id,type}
  * runtime-pm: Simplify vendor/product match
  * add help and verison user commands
  * Add a power-stats status command
  * Separate power sysfs attributes and add sysfs status attribute
  * Add device type 'sd' to default blacklist
  * Fix rpm spec file for new installable files
  * Return the cpu governor string from the function
- Remove laptop-mode-tools-1.72.2-fix-name-gui.patch
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through the -mini flavors.
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Sun Sep 16 2018 antoine.belvire@opensuse.org
- Update to version 1.72.2:
  + Extend blacklist device types to include devices of type 'sd'
    (gh#rickysarraf/laptop-mode-tools#123).
- Changes from version 1.72.1:
  + RPM spec file fixes.
- Changes from version 1.72:
  + Switch to PyQt5 and Python3.
  + Add btrfs to list of filesystems for which we can set commit
    interval.
  + Add pkexec invocation script.
  + Add desktop file to upstream repo and invoke script.
  + Update installer to includes gui wrappers.
  + Install new SVG pixmap.
  + Control all available cards in radeon-dpm.
  + Prefer to use the new runtime pm autosuspend_delay_ms
    interface.
  + tolerate broken device interfaces quietly.
  + runtime-pm: Make {black,white}lists work with non-USB devices.
  + send echo errors to verbose log.
  + Extend blacklist by device types of devtype.
- See https://github.com/rickysarraf/laptop-mode-tools/releases
  for changes introduced in releases 1.70 and 1.71.
- Fix wrong name for gui:
  + Add laptop-mode-tools-1.72.2-fix-name-gui.patch (picked from
    upstream).
- Clean spec file:
  + Create gui subpackage.
  + Remove compatibility with suse_version <= 1315:
  - Drop laptop-mode-tools.pm-utils-hook.
  - Drop laptop-mode-1.53-fix-pm-utils-sleep-script.diff.
  + Drop laptop-mode-1.53-install_sh.diff (not needed).
* Wed Apr 20 2016 robert@linux-source.org
- Update to version 1.69.2:
  Minor Bug fix release.
* Thu Mar 24 2016 robert@linux-source.org
- Fix source url, point to github.com
- Add org.linux.lmt.gui.policy to spec file.
- Add lmt-poll.service to %%pre/%%post/%%preun/%%postun.
- Clean-up spec file, require systemd-rpm-macro only if version is
  1315 or higher.
- Update to version 1.69.1:
  + Important Bug Fix release.
- Changes from version 1.69:
  + Wait for all forked modules to complete
  + Add new module: cputhotplug
  + CPU online/offine is reverse here
  + Fix shell syntax
  + Install policykit file
  + Detach polling daemon from main process
  + Do NOT touch speed if throttling is not set
  + Restore to MAX speed when back to AC Power
  + Fix manpage about DISABLE_ETHERNET_ON_BATTERY setting
  + Update documentation about ENABLE_LAPTOP_MODE_ON_AC setting
  + Change powersaving default for USB class devices
  + Drop usbhid from default (black)list
  + Add usb keyboard driver to the list default list
  + Be consistent with passing args to LMT from different invokers
  + Honor device plug/unplug events on a per device basis;
    like how Chromium initially submitted this patch
  + Also be consistent with option in the event parser
  + Update links in README.md
  + Update new github homepage location
  + Add lmt-config-gui shell script
* Wed Feb 10 2016 robert@linux-source.org
- Add laptop-mode.timer and lmt-poll.service to spec file
- Fix spec file when checking suse_version macro
- Update to version 1.68.1:
  + Update details about runtime-pm in manpage
  + Revert "Drop out reload"
  + Log error more descriptively
  + Write to common stderr. Do not hardcode a specific one
  + Call lmt-udev in lmt-poll. Don't call the laptop_mode binary directly.
  + Helps in a lot of housekeeping
  + Direct stderr/stdout to journal
  + Fix stdout descriptor
  + Install the new .timer and poll service
  + Use _sbindir for RPM
- Changes from version 1.68:
  + Fix all instances for BATTERY_LEVEL_POLLING
  + Group kill the polling daemon so that its child process get the same signal
  + Release the descriptor explicitly
  + Add identifier about who's our parent
  + Narrow down our power_supply subsystem event check condition
  + Fine tune the .service file
  + On my ultrabook, AC as reported as ACAD
  + Enhance lmt-udev to better work with systemd
  + Add a timer based polling for LMT. It is the equivalent of battery-polling-daemon, using systemd
  + Disable battery level polling by default, because most systems will have systemd running
  + Add documentation reference in systemd files
  + Update release-checklist
- Rebase laptop-mode-1.53-fix-pm-utils-sleep-script.diff
* Mon Jan  4 2016 rmilasan@suse.com
- Fix lmt-udev installation location (bsc#960497).
* Thu Jul 30 2015 zaitor@opensuse.org
- Update to version 1.67:
  + Relax minimum window size to accomodate low res screens.
  + Fix variable name to comply with our "constants" assuptions.
  + Get more aggressive in power saving for Intel HD Audio.
  + Account Device Mapper devices.
  + Add swsusp freeze support.
  + Switch battery-level-polling default to True.
  + Detect ethernet carrier, early and relibaly.
  + Changes the boolean setting *_ACTIVATE_SATA_POWER to a
    customizable *_SATA_POLICY, with backward-compatible defaults
    and documentation.
- Changes from version 1.66:
  + Handle device names with whitespaces.
  + Detach reliably closing all descriptors.
  + Add new Radeon power saving module.
  + Don't run LMT if it is disabled in config file.
  + GUI Tool refactoring.
- Changes from version 1.65:
  + Fix grep error on missing $device/uevent.
  + ethernet: replace sysfs/enabled by 'ip link down'.
  + wireless-iwl-power: sysfs attr enbable -> enabled.
  + wireless-iwl-power: Add iwlwifi support.
  + Use Runtime Power Managemet Framework is more robust now.
    Deprecates module usb-autosuspend.
  + Fix multiple hibernate issue.
  + When resuming, run LMT in force initialization mode.
  + Add module for Intel PState driver.
  + GUI: Implement suspend/hibernate interface.
- Rebase laptop-mode-1.49-new-dirty-ratio-defaults.diff.
- Package new module-helper pm-freeze.
* Fri Jul 24 2015 tchvatal@suse.com
- Make the previous commit work on openSUSE42 and SLE12, the
  pm-utils is not needed on 13.2 either
* Fri Jul 10 2015 werner@suse.de
- Make it build without pm-utils
* Fri Jun 19 2015 tchvatal@suse.com
- Clean up all various rpmlint warnings
* Wed Dec 18 2013 p.drouand@gmail.com
- Update to version 1.64
  + Don't touch USB Controller power settings. The individual devices,
    when plugged in, while on battery, inherit the power settings
    from the USB controller
  + start-stop-programs: add support for systemd.
  + Replace hardcoded path to udevadm with "which udevadm".
  + Honor .conf files only.
  + Make '/usr/lib' path configurable. This is especially useful for
    systems that use /usr/lib64, or /lib64 directly
  + Don't call killall with the -g argument.
  + Fix RPM Spec file build errors
- Changes from 1.63
  + Kick the power savings back in, as soon as the stick is unplugged
  + Release lock descriptors in start-stop-programs module.
  + Add option to disable alarm level check. This is helpful if
    you have a broken battery reporting incorrect states
  + Check for external helper application's presence. And if not
    available, handle it.
  + Added PCIe ASPM module.
  + Do not ship the board-specific/ folder in default installs
- Remove AUTHORS section
- Remove laptop-mode-1.49-initscript.diff and
  laptop-mode-1.62-customize-installation-of-udev-systemd-files.patch;
  fixed on upstream release
- Switch to systemd
* Sun Aug 11 2013 seife+obs@b1-systems.com
- own all directories in /usr/lib/pm-utils/* to prevent build
  failure in case the pm-utils packaging changes again
* Fri Mar  8 2013 rmilasan@suse.com
- laptop-mode-1.62-customize-installation-of-udev-systemd-files.patch:
  introduce $LIB_D in install.sh so we can customize the installation
  of systemd/udev files.
- drop laptop-mode-1.60-local-can-only-be-used-in-a-function.patch:
  not need it anymore as 1.62 version has the fix.
* Mon Feb  4 2013 wstephenson@suse.com
- update to 1.62:
  * Add systemd support
  * Be specific on what file systems we want to handle. Given the
    wide range of file systems Linux has, we don't want to consider
    them all as not all of them fall under the power saving scenarios.
  * Factor out some common code
  * Do not touch autonegotiation settings. Fiddling with
    auto-negotiation settings can cause more problems and the
    standards expect them to be always on
  * Trim mount point display
  * Organize state/STATE tracking so that we get actual results.
  * cleaner output when asking status.
  * Append to stdout/stderr to avoid truncating file logs
  * Fix spec file for RPM syntax
- fix some rpmlint warnings
* Wed Jul 25 2012 rmilasan@suse.com
- Local variables can only be used in a function.
  add: laptop-mode-1.60-local-can-only-be-used-in-a-function.patch
* Fri Apr 13 2012 rmilasan@suse.com
- update to 1.60:
  * Check for block device's existence. Thanks to Simon Que.
  * Add suspend/resume helper tools: pm-helper, pm-suspend, pm-hibernate.
  * What laptop-mode-tools is stopped from init, also kill polling daemon.
  * Reliable and much better locking mechanics.
  * Make polling dameon lock safe.
  * Make lmt-udev distro neutral. Thanks to Simon Que.
  * Change Intel HDA Audio's default power save timeout to 2 seconds.
* Thu Sep 15 2011 hmacht@suse.de
- update to 1.59 (excerpt):
  - add support for kernel 3.x (this makes
    laptop-mode-tools-1.57-kernel3.0.patch superfluous)
  - add USB auto-suspend whitelist
  - Check for files instead of kernel version numbers
  - Enable new in-kernel polling mechanism for block devices
    (Debian BTS: #617705, #574867)
  - Add new module nmi-watchdog to handle NMI Watchdog related power
    savings. Thanks to Quentin Denis for the report
  - More minor fixes...
* Wed Jul 20 2011 aj@suse.de
- Support kernel 3.0
- Remove dependency on haldaemon since hal is an optional
  requirement, the package can work without it just fine.
- Update to 1.57:
  * many fixes
  * support for newer kernels
  * Add a new "exec-commands" module
  * Updated manpages
* Tue Dec  7 2010 coolo@novell.com
- prereq init script haldaemon
* Thu Feb 25 2010 ro@suse.de
- drop laptop-mode-1.49-moblin-disable-control-hd-powermgmt.patch
  again which was just changin a setting from another patch
  (laptop-mode-1.49_conf.diff).
  upstream has CONTROL_HD_POWERMGMT="auto" now
- update to 1.53
  * Add global enable/disable switch for laptop-mode-tools
  * Add scheduler power saving module for SMT processors. Thanks to John
    Reilly.
  * Add a new "Auto Modules" mode which enables all modules whitelisted as
    auto with a single configuration setting, ENABLE_AUTO_MODULES.
  * Add LM/NOLM option for Intel SATA Power Management
  * Do a check before trying to write to the SuperHE Control File
- update to 1.52
  * Initialize DEBUG to 0 by default. THanks to Matthijs Kooijman for pointing
    it out.
  * Add an option to completely disable ethernet devices when on battery.
  * Introduce hooks to enable debug mode for individual modules
  * Use iwconfig to determine device type for iwlwifi devices also
  * Collect the correct exit code for iwconfig execution.
  * Use iwconfig in wireless-iwl-power. Thanks to Darren Hoo for spotting it
  * Handle spaces in mount point names. Thanks to Louis Simard for the patch
  * Clarify about Global Debug mode and Module Specific Debug mode.
  * Fix incorrect variable reference in video-out module. Thanks to Hans Werner
    for noticing that.
- update to 1.51
  * Add option to blacklist usb devices by their device id.
    Thanks to ich@phuk.ath.cx for the patch
  * Trigger timer change for power mgmt by doing a device open/close
    The open/close operation can fail if the audio device is busy.
    Since this failure is non-fatal (worst case is that the timer changes
    don't get activated), we don't bother if it was successful or not.
  * Add support for EeePC FSB Control. Thanks to James Rayner
  * Update iwlwifi power modes. Thanks to Clemens Buchacher
    See Debian BTS: #540639
  * Use the standard pm-hibernate script from pm-utils for hibernation
    See Debian BTS: #541447
  * Check if wireless device is disabled before attempting to power configure it
    Thanks to Clemens Buchacher. See Debian BTS: #541997
  * On speed change, an ethernet device can lose connectivity. Document that in
    the config file
- update to 1.50
  * Ship pm-utils hooks in /usr/lib/ and not in /etc/pm/
    Distributions will always want to have customized settings in /etc
    and default upstream settings in /usr/lib. See LP: #384875
  * Fix incorrect explanation of Intel HDA Power Savings. See Debian
    BTS: #532733
  * Don't clutter screen with print messages.
  * Add patch from Mulyadi Santosa that adds ability to lm-profiler to show
    read/write frequency of each collected program. Thank you.
  * Enhance usb-autosuspend module to be executed under conditions. Also explain
    the weirdness of broken usb drivers. Fixes Debian Bug #535051
  * Do the test comparision of integeres using string operators. Fixes Debian
    Bug #535650
  * Run pidof with the -x Script Mode switch. Thanks Matthijs Kooijman
  * Disconnect descriptors when backgrounding a script. Thanks Matthijs Kooijman
  * Add option to run in shell debug mode
  * Add a spec file to generate an RPM package
* Fri Dec  4 2009 jlee@novell.com
- Add laptop-mode-1.49-moblin-enable-intel-hda-powersave.patch for
  enable audio power saving even using ac-power.
* Thu Nov 19 2009 jlee@novell.com
- Add laptop-mode-1.49-moblin-disable-control-hd-powermgmt.patch to
  disable the APM level setup to harddrive. (bug #545681)
* Mon Oct  5 2009 seife@opensuse.org
- fix/workaround laptop-mode-tools causing garbage in the pm-utils
  suspend / hibernate logfile
* Fri Jun 26 2009 seife@suse.de
- update to 1.49. Notable changes:
  - use syslog
  - better diagnostic messages
  - most of the other changes are unused in this package, see the
    changelog for more information
- adjust dirty_ratio defaults to new kernel's defaults
* Fri Jan 23 2009 seife@suse.de
- fix udevadm version check (bnc#468848), remove old patches
* Thu Jan 15 2009 seife@suse.de
- update to 1.45
  - various improvements, most are not used in this package
  - removed bashisms
  - AC adapter fixes
  - minor optimizations
  - manpage fixes
* Fri Dec 12 2008 hmacht@suse.de
- fix enabling of laptop-mode by default:
  Use %%insserv_force_if_yast instead of %%insserv_and_fillup to
  enable laptop-mode-tools by default (fate#304737)
* Wed Sep 24 2008 ro@suse.de
- use udevadm info instead of udevinfo
* Tue Sep 16 2008 hmacht@suse.de
- fate#304737
  start laptop-mode-tools by default
  remount devices with relatime when on battery
  set hard dist power management to 128 when on battery
* Tue Aug 19 2008 seife@suse.de
- Add "Default-Start:" and "Default-Stop:" to initscript
* Thu May  8 2008 seife@suse.de
- build fix
- add README.SUSE
- enhance the init script
- pm-utils integration
* Wed May  7 2008 seife@suse.de
- initial submission, version 1.41
